@@ -9,9 +9,10 @@ from typing import Any
 
 from . import converters
 from sqlconstructor.utils.classes.string_convertible import StringConvertible
+from sqlconstructor.utils.classes.container_convertible import ContainerConvertible
 
 
-class SqlVal(StringConvertible):
+class SqlVal(StringConvertible, ContainerConvertible):
     """
     SqlVal class is invented for better experience to convert any value to sql string.
     """
@@ -23,9 +24,3 @@ class SqlVal(StringConvertible):
 
     def __str__(self) -> str:
         return self.converted
-
-    def __add__(self, other):
-        return str(self) + str(other)
-
-    def __radd__(self, other):
-        return str(other) + str(self)
